@@ -1,11 +1,11 @@
 #' ATAforecasting: Automatic Time Series Analysis and Forecasting using Ata Method with Box-Cox Power Transformations Family and Seasonal Decomposition Techniques
 #'
 #' @description Returns ATA(p,q,phi) applied to \code{X}.
-#' The Ata method based on the modified simple exponential smoothing as described in Yapar, G. (2016) <doi:10.15672/HJMS.201614320580> , 
-#' Yapar G., Capar, S., Selamlar, H. T., Yavuz, I. (2017) <doi:10.15672/HJMS.2017.493> and Yapar G., Selamlar, H. T., Capar, S., Yavuz, I. (2019) 
-#' <doi:10.15672/hujms.461032> is a new univariate time series forecasting method which provides innovative solutions to issues faced during 
+#' The Ata method based on the modified simple exponential smoothing as described in Yapar, G. (2016) <doi:10.15672/HJMS.201614320580> ,
+#' Yapar G., Capar, S., Selamlar, H. T., Yavuz, I. (2017) <doi:10.15672/HJMS.2017.493> and Yapar G., Selamlar, H. T., Capar, S., Yavuz, I. (2019)
+#' <doi:10.15672/hujms.461032> is a new univariate time series forecasting method which provides innovative solutions to issues faced during
 #' the initialization and optimization stages of existing methods.
-#' Forecasting performance of the Ata method is superior to existing methods both in terms of easy implementation and accurate forecasting. 
+#' Forecasting performance of the Ata method is superior to existing methods both in terms of easy implementation and accurate forecasting.
 #' It can be applied to non-seasonal or seasonal time series which can be decomposed into four components (remainder, level, trend and seasonal).
 #' This methodology performed well on the M3 and M4-competition data.
 #' Returns ATA(p,q,phi) applied to \code{X}.
@@ -29,12 +29,12 @@ NULL # Instead of "_PACKAGE" to remove inclusion of \alias{ATAforecasting}
 
 #' Automatic Time Series Analysis and Forecasting using Ata Method with Box-Cox Power Transformations Family and Seasonal Decomposition Techniques
 #'
-#' \code{ATA} is a generic function for Ata Method forecasting. 
-#' The Ata method based on the modified simple exponential smoothing as described in Yapar, G. (2016) <doi:10.15672/HJMS.201614320580> , 
-#' Yapar G., Capar, S., Selamlar, H. T., Yavuz, I. (2017) <doi:10.15672/HJMS.2017.493> and Yapar G., Selamlar, H. T., Capar, S., Yavuz, I. (2019) 
-#' <doi:10.15672/hujms.461032> is a new univariate time series forecasting method which provides innovative solutions to issues faced during 
+#' \code{ATA} is a generic function for Ata Method forecasting.
+#' The Ata method based on the modified simple exponential smoothing as described in Yapar, G. (2016) <doi:10.15672/HJMS.201614320580> ,
+#' Yapar G., Capar, S., Selamlar, H. T., Yavuz, I. (2017) <doi:10.15672/HJMS.2017.493> and Yapar G., Selamlar, H. T., Capar, S., Yavuz, I. (2019)
+#' <doi:10.15672/hujms.461032> is a new univariate time series forecasting method which provides innovative solutions to issues faced during
 #' the initialization and optimization stages of existing methods.
-#' Forecasting performance of the Ata method is superior to existing methods both in terms of easy implementation and accurate forecasting. 
+#' Forecasting performance of the Ata method is superior to existing methods both in terms of easy implementation and accurate forecasting.
 #' It can be applied to non-seasonal or seasonal time series which can be decomposed into four components (remainder, level, trend and seasonal).
 #' This methodology performed well on the M3 and M4-competition data.
 #'
@@ -76,10 +76,13 @@ NULL # Instead of "_PACKAGE" to remove inclusion of \alias{ATAforecasting}
 #'		 \item{4} : multiple period with find.freq & tbats
 #'		 \item{5} : multiple period with find.freq & stl
 #' }
-#' @param accuracy.type	Accuracy measure for selection of the best model. IF NULL, \code{sMAPE} is default.
+#' @param accuracy.type	Accuracy measure for optimization of the best ATA Method forecasting. IF NULL, \code{sMAPE} is default.
 #' \itemize{
+#'		 \item{lik}		: maximum likelihood functions
+#'		 \item{sigma}	: residual variance.
 #'		 \item{MAE}		: mean absolute error.
 #'		 \item{MSE}		: mean square error.
+#'		 \item{AMSE}	: Average MSE over first `nmse` forecast horizons.
 #'		 \item{RMSE}	: root mean squared error.
 #'		 \item{MPE}		: mean percentage error.
 #'		 \item{MAPE}	: mean absolute percentage error.
@@ -93,20 +96,25 @@ NULL # Instead of "_PACKAGE" to remove inclusion of \alias{ATAforecasting}
 #'		 \item{MdAPE}	: median absolute percentage error.
 #'		 \item{sMdAPE}	: symmetric median absolute percentage error.
 #' }
+#' @param nmse If `accuracy.type == "AMSE"`, `nmse` provides the number of steps for average multistep MSE (`2<=nmse<=30`).
 #' @param level.fixed If TRUE, "pStarQ"  --> First, fits ATA(p,0) where p = p* is optimized for q=0. Then, fits ATA(p*,q) where q is optimized for p = p*.
-#' @param trend.fixed If TRUE, "pBullet" --> Fits ATA(p,1) where p = p* is optimized for q = 1.
-#' @param trend.search If TRUE, "qBullet" --> Fits ATA(p,q) where p = p* is optimized for q = q* (q > 0). Then, fits ATA(p*,q) where q is optimized for p = p*.
+#' @param trend.opt When \code{trend.opt},
+#' \itemize{
+#'		 \item{none} : none
+#'		 \item{fixed} : "pBullet" --> Fits ATA(p,1) where p = p* is optimized for q = 1.
+#'		 \item{search} : "qBullet" --> Fits ATA(p,q) where p = p* is optimized for q = q* (q > 0). Then, fits ATA(p*,q) where q is optimized for p = p*.
+#' }
 #' @param h The number of steps to forecast ahead.
-#' When the parameter is NULL; if the frequency of \code{X} is 4 the parameter is set to 8; if the frequency of \code{X} is 12 the parameter is set to 18; the parameter is set to 6 for other cases.
+#' When the parameter is NULL; if the frequency of \code{X} is 4, the parameter is set to 8; if the frequency of \code{X} is 12, the parameter is set to 18; the parameter is set to 6 for other cases.
 #' @param partition.h If \code{Y} is NULL, this parameter divides \code{X} into two parts: training set (in-sample) and test set (out-sample). \code{partition.h} is number of periods for forecasting and size of test set.
 #' If the value is between 0 and 1, percentage of length is active. If \code{holdout} is TRUE, this parameter will be same as \code{h} for defining holdout set.
 #' @param holdout Default is FALSE. If TRUE, ATA Method uses the holdout forecasting for accuracy measure to select the best model. In holdout forecasting, the last few data points are removed from the data series.
-#' The remaining historical data series is called in-sample data (training set), and the holdout data is called out-of-sample data (holdout set).
+#' The remaining historical data series is called in-sample data (training set), and the holdout data is called validation set (holdout set).
 #' If TRUE, partition.h will used for holdout data.
 #' @param holdout.adjustedP Default is TRUE. If TRUE, parP will be adjusted by length of training - validation sets and in-sample set when the holdout forecasting is active.
 #' @param holdin Default is FALSE. If TRUE, ATA Method uses the hold-in forecasting for accuracy measure to select the best model. In hold-in forecasting, the last h-length data points are used for accuracy measure.
 #' @param transform.order If "before", Box-Cox transformation family will be applied and then seasonal decomposition techniques will be applied. If "after", seasonal decomposition techniques will be applied and then Box-Cox transformation family will be applied.
-#' @param transform.method Transformation method  --> "Box_Cox", "Sqrt", "Reciprocal", "Log", "NegLog", "Modulus", "BickelDoksum", "Manly", "Dual", "YeoJohnson", "GPower", "GLog". If the transformation process needs shift parameter, 
+#' @param transform.method Transformation method  --> "Box_Cox", "Sqrt", "Reciprocal", "Log", "NegLog", "Modulus", "BickelDoksum", "Manly", "Dual", "YeoJohnson", "GPower", "GLog". If the transformation process needs shift parameter,
 #' \code{ATA.Transform} will calculate required shift parameter automatically.
 #' @param transform.attr Attributes set for Box-Cox transformation. If NULL, bcMethod = "loglik", bcLower = 0, bcUpper = 1, bcBiasAdj = FALSE. If you want to change, please use \code{ATA.BoxCoxAttr} function and its output.
 #' @param lambda Box-Cox power transformation family parameter. If NULL, data transformed before model is estimated.
@@ -118,7 +126,7 @@ NULL # Instead of "_PACKAGE" to remove inclusion of \alias{ATAforecasting}
 #' @param ci.level Confidence Interval levels for forecasting.
 #' @param start.phi Lower boundary for searching \code{parPHI}.If NULL, 0 is default.
 #' @param end.phi Upper boundary for searching \code{parPHI}. If NULL, 1 is is default.
-#' @param size.phi Increment step for searching \code{parPHI}. If NULL, 0.05 is default.
+#' @param size.phi Increment step for searching \code{parPHI}. If NULL, the step size will be determined as the value that allows the bounds for the optimised value of \code{parPHI} to be divided into 20 equal parts.
 #' @param negative.forecast Negative values are allowed for forecasting. Default value is TRUE. If FALSE, all negative values for forecasting are set to 0.
 #' @param print.out Default is TRUE. If FALSE, summary of ATA Method is not shown.
 #' @param plot.out Default is TRUE. If FALSE, graphics of ATA Method are not shown.
@@ -140,18 +148,19 @@ NULL # Instead of "_PACKAGE" to remove inclusion of \alias{ATAforecasting}
 #' 		 \item{h}		      : The number of steps to forecast ahead.
 #' 		 \item{forecast}	: Point forecasts as a time series.
 #' 		 \item{out.sample}: Test values as a time series.
-#' 		 \item{method}		: The name of the optimum forecasting method as a character string.
+#' 		 \item{method}		: The name of the optimum forecasting method as a character string for ATA(P,Q,PHI)(Error,Trend,Season).
 #' 		 \item{initial.level}     : Selected initial level values for the time series forecasting method.
 #' 		 \item{initial.trend}     : Selected initial trend values for the time series forecasting method.
 #' 		 \item{level.fixed}       : A choice of optional level-fixed trended methods.
-#' 		 \item{trend.fixed}       : A choice of optional trend-fixed trended methods.
-#' 		 \item{trend.search}      : A choice of optional trend and level optimized trended methods if q > 1.
+#'     \item{trend.opt}       : A choice of optional trend and level optimized trended methods (none, trend.fixed or trend.search).
 #' 		 \item{transform.method}  : Box-Cox power transformation family method  --> Box_Cox, Sqrt, Reciprocal, Log, NegLog, Modulus, BickelDoksum, Manly, Dual, YeoJohnson, GPower, GLog.
 #' 		 \item{transform.order}   : Define how to apply Box-Cox power transformation techniques, before or after seasonal decomposition.
 #' 		 \item{lambda}  	: Box-Cox power transformation family parameter.
 #' 		 \item{shift}		  : Box-Cox power transformation family shifting parameter.
 #' 		 \item{accuracy.type}		  : Accuracy measure that is chosen for model selection.
+#' 		 \item{nmse}		  : The number of steps for average multistep MSE.
 #' 		 \item{accuracy} 	: In and out sample accuracy measures and its descriptives that are calculated for optimum model are given.
+#' 		 \item{par.specs} 	: Parameter sets for Information Criteria.
 #' 		 \item{holdout}		: Holdout forecasting is TRUE or FALSE.
 #' 		 \item{holdout.training} 	: Training set in holdout forecasting.
 #' 		 \item{holdout.validation}: Validation set in holdout forecasting.
@@ -175,7 +184,7 @@ NULL # Instead of "_PACKAGE" to remove inclusion of \alias{ATAforecasting}
 #' \code{tbats}, \code{seasadj}, \code{seasonal}.
 #'
 #' @references
-#' 
+#'
 #' #'\insertRef{yapar2017mses}{ATAforecasting}
 #'
 #' #'\insertRef{yapar2018mhes}{ATAforecasting}
@@ -185,7 +194,7 @@ NULL # Instead of "_PACKAGE" to remove inclusion of \alias{ATAforecasting}
 #' #'\insertRef{yapar2019ata}{ATAforecasting}
 #'
 #' @keywords Ata forecast accuracy ts msts
-#' 
+#'
 #' @importFrom forecast findfrequency
 #' @importFrom stats cycle frequency ts tsp tsp<-
 #' @importFrom Rdpack reprompt
@@ -208,9 +217,9 @@ ATA <- function(X, Y = NULL,
                 seasonal.test.attr = NULL,
                 find.period = NULL,
                 accuracy.type = NULL,
+                nmse = 3,
                 level.fixed = FALSE,
-                trend.fixed = FALSE,
-                trend.search = FALSE,
+                trend.opt = "none",
                 h = NULL,
                 partition.h = NULL,
                 holdout = FALSE,
@@ -242,31 +251,21 @@ ATA <- function(X, Y = NULL,
   }
   if (is.null(parPHI)){
     parPHI <- "opt"
-    if (is.null(size.phi)){
-      size.phi <- 0.05
-    }
-    if (is.null(start.phi)){
-      start.phi <- 0
-    }
-    if (is.null(end.phi)){
-      end.phi <- 1
-    }
-  }else {
-    if (parPHI == "opt"){
-      if (is.null(size.phi)){
-        size.phi <- 0.05
-      }
+  }
+  if (parPHI == "opt"){
       if (is.null(start.phi)){
-        start.phi <- 0
+        start.phi <- 0.4
       }
       if (is.null(end.phi)){
         end.phi <- 1
       }
-    }else {
+      if (is.null(size.phi)){
+        size.phi <- signif((end.phi - start.phi) / 20, 6)
+      }
+  }else {
       start.phi <- parPHI
       end.phi <- parPHI
       size.phi <- 1
-    }
   }
   if (!is.null(seasonal.period)){
     find.period <- 0
@@ -278,50 +277,62 @@ ATA <- function(X, Y = NULL,
     s.frequency <- frequency(X)
     seasonal.period <- frequency(X)
   }
-  if (find.period!=0) {
+  if (find.period!=0){
     if(find.period==1){
       seasonal.period <- find.freq(X)
-	  seasonal.test <- TRUE
+	    seasonal.test <- TRUE
     }else if(find.period==2){
       seasonal.period <- forecast::findfrequency(X)
-	  seasonal.test <- TRUE
+	    seasonal.test <- TRUE
     }else if (find.period==3){
       seasonal.period <- find.multi.freq(X)
       seasonal.model=="stR"
-	  seasonal.test <- TRUE
+	    seasonal.test <- TRUE
     }else if (find.period==4){
       seasonal.period <- find.multi.freq(X)
       seasonal.model=="tbats"
-	  seasonal.test <- TRUE
+	    seasonal.test <- TRUE
     }else if (find.period==5){
       seasonal.period <- find.multi.freq(X)
       seasonal.model=="stl"
-	  seasonal.test <- TRUE
+	    seasonal.test <- TRUE
     }else {
       return("find.period must be integer and between 0 and 5. ATA Method was terminated!")
     }
     s.frequency <- seasonal.period
   }
-  if (length(s.frequency)>1){
+  if (length(s.frequency)>1 & length(seasonal.model)==1){
     if (seasonal.model != "tbats" & seasonal.model != "stR" & seasonal.model != "stl"){
-      seasonal.model <- "stl"
-	  seasonal.test <- TRUE
+       seasonal.model <- "stl"
+	     seasonal.test <- TRUE
+       warning("Seasonal decompostion method has been set to 'stl' because invalid method is chosen.")
     }
+  }else if (length(s.frequency)>1 & is.null(seasonal.model)){
+    seasonal.model <- c("stl","stR","tbats")
+    warning("Seasonal decompostion method has been set to c('stl', 'stR', 'tbats').")
   }else {
-	if (s.frequency > 1 & is.null(seasonal.model)){
-		seasonal.model <- "decomp"
-		seasonal.test <- TRUE
-	}
+  	if (s.frequency > 1 & is.null(seasonal.model)){
+  		seasonal.model <- "decomp"
+  		seasonal.test <- TRUE
+      warning("Seasonal decompostion method has been set to 'decomp'.")
+  	}
   }
   if (is.null(accuracy.type)){
     accuracy.type <- "sMAPE"
   }
-  if (trend.search==TRUE){
+  if (trend.opt=="search"){
+    trend.search <- TRUE
     level.fixed <- FALSE
     trend.fixed <- FALSE
-  }else if (level.fixed==TRUE & trend.fixed==TRUE){
+    warning("level.fixed parameter has been turned FALSE as trend.opt is set 'search'")
+  }else if (trend.opt=="fixed"){
+    trend.search <- FALSE
     level.fixed <- FALSE
     trend.fixed <- TRUE
+    warning("level.fixed parameter has been turned FALSE as trend.opt is set 'search'")
+  }else if (trend.opt=="none"){
+    trend.search <- FALSE
+    trend.fixed <- FALSE
   }else {
   }
   if (is.null(initial.level)){
@@ -342,6 +353,9 @@ ATA <- function(X, Y = NULL,
   }else {
 	seasonal.test <- FALSE
   }
+  if (min(s.frequency) == 1 & seasonal.test == TRUE){
+    stop("'period' can not be equal 1 if 'seasonal.test' is set TRUE.")
+  }
   if (is.null(transform.attr)) {
     boxcox_attr_set <- ATA.BoxCoxAttr()
   }else {
@@ -350,6 +364,18 @@ ATA <- function(X, Y = NULL,
   if (holdout == TRUE & holdin == TRUE){
     return("Only one parameter of the two parameters (holdout or holdin) must be selected. Please choose one one of them. ATA Method was terminated!")
   }
+  if (holdout == TRUE & accuracy.type == "AMSE") {
+    accuracy.type <- "sMAPE"
+    warning("ATA Method does not support 'AMSE' for 'holdout' forecasting. 'accuracy.type' is set to 'sMAPE'.")
+  }
+  if (nmse > 30 & accuracy.type == "AMSE") {
+    nmse <- 30
+    warning("'nmse' must be less than 30. 'nmse' is set to 30.")
+  }else if ((is.null(nmse) | nmse <= 1) & accuracy.type == "AMSE") {
+    nmse <- 3
+    warning("'nmse' must be greater than 1. 'nmse' is set to 3.")
+  }else{
+  }
 
   Qlen <- length(parQ)
   Plen <- length(parP)
@@ -388,8 +414,10 @@ ATA <- function(X, Y = NULL,
       }
     }
   }
-  if ((accuracy.type != "MAE" & accuracy.type != "MSE" & accuracy.type != "RMSE" & accuracy.type != "MPE" & accuracy.type != "MAPE" & accuracy.type != "sMAPE" & accuracy.type != "MASE" & accuracy.type != "OWA" & accuracy.type != "MdAE" & accuracy.type != "MdSE" & accuracy.type != "MdPE" & accuracy.type != "MdAPE" & accuracy.type != "sMdAPE") | !is.character(accuracy.type) | length(accuracy.type) > 1){
-    return("Accuracy Type value must be string and it must get one value: MAE or MSE or MPE or MAPE or sMAPE or MASE or MdAE or MdSE or MdPE or MdAPE or sMdAPE. ATA Method was terminated!")
+  if ((accuracy.type != "lik" & accuracy.type != "sigma" & accuracy.type != "MAE" & accuracy.type != "MSE" & accuracy.type != "AMSE" & accuracy.type != "RMSE" &
+          accuracy.type != "MPE" & accuracy.type != "MAPE" & accuracy.type != "sMAPE" & accuracy.type != "MASE" & accuracy.type != "OWA" & accuracy.type != "MdAE" &
+          accuracy.type != "MdSE" & accuracy.type != "MdPE" & accuracy.type != "MdAPE" & accuracy.type != "sMdAPE") | !is.character(accuracy.type) | length(accuracy.type) > 1){
+    return("Accuracy Type value must be string and it must get one value: MAE or MSE or AMSE or MPE or MAPE or sMAPE or MASE or MdAE or MdSE or MdPE or MdAPE or sMdAPE. ATA Method was terminated!")
   }
   if (!is.null(model.type)){
     if ((model.type != "A" & model.type != "M") | !is.character(model.type) | length(model.type) > 1){
@@ -412,9 +440,9 @@ ATA <- function(X, Y = NULL,
     }
   }
   if (!is.null(transform.method)){
-    if ((transform.method != "Box_Cox" & transform.method != "Box_Cox_Shift" & transform.method != "Modulus" & transform.method != "BickelDoksum" & transform.method != "Dual"  & transform.method != "Manly"  & transform.method != "Sqrt" & transform.method != "SqrtShift" & 
-         transform.method != "YeoJohnson" & transform.method != "GPower" & transform.method != "GLog" & transform.method != "Log" & transform.method != "Reciprocal" & transform.method !="ReciprocalShift" & transform.method != "NegLog" & 
-		 transform.method != "LogShift") | !is.character(transform.method) | length(transform.method) > 1){
+    if ((transform.method != "Box_Cox" & transform.method != "Box_Cox_Shift" & transform.method != "Modulus" & transform.method != "BickelDoksum" & transform.method != "Dual"  & transform.method != "Manly"  & transform.method != "Sqrt" & transform.method != "SqrtShift" &
+         transform.method != "YeoJohnson" & transform.method != "GPower" & transform.method != "GLog" & transform.method != "Log" & transform.method != "Reciprocal" & transform.method !="ReciprocalShift" & transform.method != "NegLog" &
+		     transform.method != "LogShift") | !is.character(transform.method) | length(transform.method) > 1){
       return("Transform Method value must be string. Please select a valid Box-Cox transformation technique. ATA Method was terminated!")
     }
   }
@@ -445,7 +473,7 @@ ATA <- function(X, Y = NULL,
     }
   }else {
     if (!is.null(partition.h)){
-      part_h <- ifelse(partition.h > 0 & partition.h < 1, floor(length(X) * partition.h), partition.h)
+      part_h <- as.integer(ifelse(partition.h > 0 & partition.h < 1, floor(length(X) * partition.h), partition.h))
       OSLen <- length(X)- part_h
       ISLen <- length(X)
       OutSample <- X[(OSLen+1):ISLen]
@@ -454,11 +482,18 @@ ATA <- function(X, Y = NULL,
       X <- ts(X, frequency = tspX[3], start = tspX[1])
       h <- length(OutSample)
     }else {
+      m <- max(s.frequency)
       if (is.null(h)){
-        if (max(s.frequency)==4){
+        if (m==4){
           h <- 8
-        }else if (max(s.frequency)==12){
-          h <- 18
+        }else if (m==5){
+          h <- 10
+        }else if (m==7){
+          h <- 14
+        }else if (m==12){
+          h <- 24
+        }else if (m==24){
+          h <- 48
         }else {
           h <- 6
         }
@@ -469,24 +504,34 @@ ATA <- function(X, Y = NULL,
         partition.h	<- h
       }
     }
-  }
+   }
   orig.X <- ts(X, frequency = firstTspX[3], start = firstTspX[1])
   tsp_ny <- tsp(forecast::msts(orig.X, start=tsp(orig.X)[1], seasonal.periods = s.frequency))
   fsample <- ts(OutSample, frequency = max(s.frequency), start = tsp_ny[2] + ifelse(tsp_ny[3]>1, 1/tsp_ny[3], 1))
   freqYh <- cycle(fsample)
+  par.specs <- list("p" = parP, "q" = parQ, "phi" = parPHI,
+                "trend" = ifelse(is.null(model.type), "opt", ifelse(parQ==0, "N", model.type)),
+                "seasonal" = ifelse(is.null(seasonal.type), "opt", seasonal.type),
+                "initial_level" = ifelse(initial.level==FALSE, NA, TRUE),
+                "initial_trend" = ifelse(initial.trend==FALSE, NA, TRUE))
+  par_specs <- c(stats::na.omit(unlist(par.specs)))
+  np <- length(par_specs)
+  if (np >= length(X) - 1) {
+    stop("Not enough data to estimate this ATA method.")
+  }
   if (transform.order == "before"){
     ChgX <- ATA.Transform(X,tMethod=transform.method, tLambda=lambda, tShift=shift, bcMethod = boxcox_attr_set$bcMethod, bcLower = boxcox_attr_set$bcLower, bcUpper = boxcox_attr_set$bcUpper)
     X <- forecast::msts(ChgX$trfmX, start=firstTspX[1], seasonal.periods = s.frequency)
     lambda <- ChgX$tLambda
     shift <- ChgX$tShift
     if (length(seasonal.type)==1 & length(seasonal.model)==1){
-      my_list <- AutoATA.Single(X, parP, parQ, model.type, seasonal.test, seasonal.model, seasonal.type, s.frequency, h, accuracy.type,
+      my_list <- SubATA.Single(X, parP, parQ, model.type, seasonal.test, seasonal.model, seasonal.type, s.frequency, h, accuracy.type,
                                 level.fixed, trend.fixed, trend.search, start.phi, end.phi, size.phi, initial.level, initial.trend, transform.method,
-                                lambda, shift, orig.X, OutSample, seas_attr_set, freqYh, ci.level, negative.forecast, boxcox_attr_set, holdout, partition.h, holdout.adjustedP, holdin)
+                                lambda, shift, orig.X, OutSample, seas_attr_set, freqYh, ci.level, negative.forecast, boxcox_attr_set, holdout, partition.h, holdout.adjustedP, holdin, nmse)
     }else {
-      my_list <- AutoATA.Multiple(X, parP, parQ, model.type, seasonal.test, seasonal.model, seasonal.type, s.frequency, h, accuracy.type,
+      my_list <- SubATA.Multiple(X, parP, parQ, model.type, seasonal.test, seasonal.model, seasonal.type, s.frequency, h, accuracy.type,
                                   level.fixed, trend.fixed, trend.search, start.phi, end.phi, size.phi, initial.level, initial.trend, transform.method,
-                                  lambda, shift, orig.X, OutSample, seas_attr_set, freqYh, ci.level, negative.forecast, boxcox_attr_set, holdout, partition.h, holdout.adjustedP, holdin)
+                                  lambda, shift, orig.X, OutSample, seas_attr_set, freqYh, ci.level, negative.forecast, boxcox_attr_set, holdout, partition.h, holdout.adjustedP, holdin, nmse)
     }
   }else {
     if (!is.null(transform.method)){
@@ -494,26 +539,30 @@ ATA <- function(X, Y = NULL,
       warning("model.type parameter has been set as 'M' because of a transformation techniques from Box-Cox power transformation family selected.")
     }
     if (length(seasonal.type)==1 & length(seasonal.model)==1){
-      my_list <- AutoATA.SingleO(X, parP, parQ, model.type, seasonal.test, seasonal.model, seasonal.type, s.frequency, h, accuracy.type,
+      my_list <- SubATA.SingleO(X, parP, parQ, model.type, seasonal.test, seasonal.model, seasonal.type, s.frequency, h, accuracy.type,
                                  level.fixed, trend.fixed, trend.search, start.phi, end.phi, size.phi, initial.level, initial.trend, transform.method,
-                                 lambda, shift, orig.X, OutSample, seas_attr_set, freqYh, ci.level, negative.forecast, boxcox_attr_set, holdout, partition.h, holdout.adjustedP, holdin)
+                                 lambda, shift, orig.X, OutSample, seas_attr_set, freqYh, ci.level, negative.forecast, boxcox_attr_set, holdout, partition.h, holdout.adjustedP, holdin, nmse)
     }else {
-      my_list <- AutoATA.MultipleO(X, parP, parQ, model.type, seasonal.test, seasonal.model, seasonal.type, s.frequency, h, accuracy.type,
+      my_list <- SubATA.MultipleO(X, parP, parQ, model.type, seasonal.test, seasonal.model, seasonal.type, s.frequency, h, accuracy.type,
                                    level.fixed, trend.fixed, trend.search, start.phi, end.phi, size.phi, initial.level, initial.trend, transform.method,
-                                   lambda, shift, orig.X, OutSample, seas_attr_set, freqYh, ci.level, negative.forecast, boxcox_attr_set, holdout, partition.h, holdout.adjustedP, holdin)
+                                   lambda, shift, orig.X, OutSample, seas_attr_set, freqYh, ci.level, negative.forecast, boxcox_attr_set, holdout, partition.h, holdout.adjustedP, holdin, nmse)
     }
   }
+
+  my_list$transform.order <- transform.order
+  my_list$trend.opt <- trend.opt
   executionTime <- proc.time() - ptm
   end.time <- Sys.time()
-  my_list$transform.order <- transform.order
   my_list$execution.time <- executionTime
   my_list$calculation.time <- round(as.double(difftime(end.time, start.time,units="sec")),4)
   attr(my_list, "class") <- "ATA"
   if (plot.out==TRUE) {
     ATA.plot(my_list)
   }
+  if (print.out==TRUE) {
+    ATA.print(my_list)
+  }
   gc()
-  ATA.print(my_list)
   return(my_list)
 }
 
@@ -536,8 +585,8 @@ ATA.print <- function(object,...)
     if (x$level.fixed==TRUE){
       cat("   level.fixed: TRUE","\n\n")
     }
-    if (x$trend.fixed==TRUE){
-      cat("   trend.fixed: TRUE","\n\n")
+    if (x$trend.opt!="none"){
+      cat(paste("   trend optimization method: trend.", x$trend.opt, "\n\n", sep=""))
     }
     if(!is.null(x$transform.method)){
       cat(paste("   '",x$transform.method, "' transformation method was selected.","\n\n", sep=""))
@@ -557,9 +606,9 @@ ATA.print <- function(object,...)
     cat(paste("   forecast horizon:",x$h, "\n\n"))
     cat(paste("   accuracy.type:",x$accuracy.type, "\n\n"))
 
-    cat("In-Sample Accuracy Measures:","\n")
-    stats <- c(x$accuracy$MAE$inSample$MAE, x$accuracy$MSE$inSample$MSE, x$accuracy$MSE$inSample$RMSE, x$accuracy$MPE$inSample$MPE, x$accuracy$MAPE$inSample$MAPE, x$accuracy$sMAPE$inSample$sMAPE, x$accuracy$MASE$inSample$MASE, x$accuracy$OWA$inSample$OWA)
-    names(stats) <- c("MAE", "MSE", "RMSE", "MPE", "MAPE", "sMAPE", "MASE", "OWA")
+    cat("Model Fitting Measures:","\n")
+    stats <- c(x$accuracy$fits$sigma2, x$accuracy$fits$loglik, x$accuracy$MAE$inSample$MAE, x$accuracy$MSE$inSample$MSE, x$accuracy$MSE$inSample$RMSE, x$accuracy$MPE$inSample$MPE, x$accuracy$MAPE$inSample$MAPE, x$accuracy$sMAPE$inSample$sMAPE, x$accuracy$MASE$inSample$MASE, x$accuracy$OWA$inSample$OWA)
+    names(stats) <- c("sigma2", "loglik", "MAE", "MSE", "RMSE", "MPE", "MAPE", "sMAPE", "MASE", "OWA")
     cat("\n")
     print(stats)
     cat("\n")
@@ -586,6 +635,13 @@ ATA.print <- function(object,...)
     print(stats)
     cat("\n")
 
+    cat("Information Criteria:","\n")
+    stats <- c(x$accuracy$fits$AIC, x$accuracy$fits$AICc, x$accuracy$fits$BIC)
+    names(stats) <- c("AIC", "AICc", "BIC")
+    cat("\n")
+    print(stats)
+    cat("\n")
+
     stats <- c(x$execution.time[1], x$execution.time[2], x$execution.time[3])
     names(stats) <- c("user","system","elapsed")
     cat("\n")
@@ -611,8 +667,8 @@ ATA.print <- function(object,...)
 #'
 #' @return a graphic output for the components of the ATAforecasting
 #'
-#' @importFrom stats cycle frequency ts tsp tsp<- 
-#' @importFrom graphics axis legend layout lines mtext par plot polygon 
+#' @importFrom stats cycle frequency ts tsp tsp<-
+#' @importFrom graphics axis legend layout lines mtext par plot polygon
 #'
 #' @export
 ATA.plot <- function(object, fcol=4, flty = 2, flwd = 2, ...)
@@ -620,7 +676,7 @@ ATA.plot <- function(object, fcol=4, flty = 2, flwd = 2, ...)
   x <- object
   oldpar <- par(no.readonly = TRUE)# save default, for resetting...
   on.exit(par(oldpar))
-  caption <- paste(ifelse(x$model.type=="A"," Additive "," Multiplicative "), x$method, sep="")
+  caption <- x$method
   xx <- x$actual
   hpred <- length(x$forecast)
   freq <- frequency(xx)
@@ -631,7 +687,7 @@ ATA.plot <- function(object, fcol=4, flty = 2, flwd = 2, ...)
   range_y <- abs(max_y - min_y)
   min_last <- floor(min_y - range_y * 0.20)
   max_last <- ceiling(max_y + range_y * 0.20)
-  range_last <- abs(max_last - min_last)
+  range_last <- signif(abs(max_last - min_last),6)
   rnd_par <- ifelse(range_last<10, 1, 0)
   dataset <- cbind(xxx,xxy)
   colnames(dataset, do.NULL = FALSE)
@@ -654,7 +710,7 @@ ATA.plot <- function(object, fcol=4, flty = 2, flwd = 2, ...)
     plot(x$level, ylab="level")
     par(mar = c(bottom=2, 4.1, top=2, 1.1))
     plot(x$residuals, ylab="residuals")
-  }else { 
+  }else {
     layout(matrix(c(1, 2, 3, 4, 5, 6), 3, 2, byrow=TRUE))
     par(mar = c(bottom=1, 4.1, top=2, 1.1))
     plot(dataset,plot.type="s", ylim=c(min_last, max_last), col=1:ncol(dataset), xlab=NULL, ylab="fitted", yaxt="n")
@@ -663,7 +719,7 @@ ATA.plot <- function(object, fcol=4, flty = 2, flwd = 2, ...)
     lines(x$forecast, lty = flty, lwd = flwd, col = fcol)
     lines(x$out.sample, lty = 1, lwd = flwd, col = fcol+2)
     legend("topleft", legend_names, col=c(1,2,fcol+2,fcol), lty=1, cex=.80, box.lty=0, text.font=2, ncol=2, bg="transparent")
-    mtext(paste(caption,"with ",ifelse(x$seasonal.type=="A","Additive","Multiplicative"), " Decomposition by '",ifelse(x$seasonal.model=="decomp","classical",x$seasonal.model),"' Method"), side = 3, line = -1.5, outer = TRUE)
+    mtext(paste(caption, " with ", ifelse(x$seasonal.model=="decomp","classical",x$seasonal.model), " decomposition method", sep=""), side = 3, line = -1.5, outer = TRUE)
     par(mar = c(bottom=1, 4.1, top=2, 1.1))
     plot(x$seasonal.adjusted,ylab="deseasonalized")
     par(mar = c(bottom=1, 4.1, top=2, 1.1))
